/*
 * This file is a part of KEMET project (Library).
 * 
 * Copyright (C) 2008 MAUPIN Fabrice
 *
 * This library is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; 
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library; 
 * if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
package org.kemet.tests.phonograms;

import java.util.Arrays;

import org.apache.log4j.Logger;
import org.junit.Test;
import org.kemet.tests.TestRoot;

/**
 * 
 * @author fabricemaupin
 * 
 * <p>
 * <b>fonctionnal tests for biliteral.</b>
 * </p>
 * 
 * @since 0.1
 * 
 */
public class TestBiliteral extends TestRoot {
	static final Logger log = Logger.getLogger("org.kemet.tests");

	/**
	 * <p>
	 * <b>sequence for test.</b>
	 * </p>
	 */
	private String[] d1;

	/**
	 * <p>
	 * <b>expected result.</b>
	 * </p>
	 */
	private String[] d1Expected;

	/**
	 * <p>
	 * <b>sequence 2 for test.</b>
	 * </p>
	 */
	private String[] d2;

	/**
	 * <p>
	 * <b>expected result 2.</b>
	 * </p>
	 */
	private String[] d2Expected;

	/**
	 * <p>
	 * <b>set the parameters before execute the tests.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	public void init() {
		// initialize the data tests...
		d1 = new String[] { "bb33", "kmm", "mnn", "prr", "pph.h.", "h)th)t",
				"mbb3", "nnn" };
		d1Expected = new String[] { "b3", "km", "mn", "pr", "ph.", "h)t",
				"mb3", "nn" };

		d2 = new String[] { "c3c", "c3c3", "m3m", "m33", "mm3", "mm33" };
		d2Expected = new String[] { "c3", "c3", "m3", "m3", "m3", "m3" };
	}

	/**
	 * <p>
	 * <b>test : detect and epurate phonetic complements.</b>
	 * </p>
	 * 
	 * throws Exception
	 * 
	 * @since 0.1
	 */
	@Test
	public void testBilEx1() throws Exception {
		String[] a1 = gm.toEpuratePhoneticComplementFromSequence(d1, 2, phInfo,
				args);
		assertEquals(Arrays.equals(a1, d1Expected), true);

		a1 = gm.toEpuratePhoneticComplementFromSequence(d2, 2, phInfo, args);
		assertEquals(Arrays.equals(a1, d2Expected), true);
	}

	/**
	 * <p>
	 * <b>test : phonetic read.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	@Test
	public void testBilEx2() {
		// tests exceptions to pronunciation particulars cases
		try {
			assertEquals(gm.toPhoneticReadWithGlobalApproach(new String[] {
					"mmj", "mj" }, false), "mam");
		} catch (Exception e) {
			assertTrue(false);
		}

		try {
			assertEquals(gm.toPhoneticReadWithGlobalApproach(new String[] {
					"mmj", "mj" }, true), "méame");
		} catch (Exception e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>test : transliteration to hieroglyphs or hieroglyphs to
	 * transliteration.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	@Test
	public void testBilEx4() {
		// tests biliteres detection in sequence (signList or transliterated
		// sequence)
		try {
			assertEquals(gm.toHieroglyphs(new String[] { "b3", "b33" }),
					"G29G29G1");
		} catch (Exception e) {
			assertTrue(false);
		}

		try {
			assertEquals(gm.toTransliteration(new String[] { "G29", "G29_G1" },
					0), "b3b33");
		} catch (Exception e) {
			assertTrue(false);
		}
	}
}
